==> libphidget22-1.0.0.20170906.tar.gz: libphidget22-1.0.0.20170906/src/class/voltageratioinput.c <==
/* Generated: Wed Jan 27 2016 14:22:18 GMT-0700 (Mountain Standard Time) */
/* Will not be regenerated. */

#include "phidgetbase.h"
#include "analogsensor.h"
#include "class/voltageratioinput.gen.h"
#include "class/voltageratioinput.gen.c"

static void
PhidgetVoltageRatioInput_errorHandler(PhidgetChannelHandle phid, Phidget_ErrorEventCode code) {
	PhidgetVoltageRatioInputHandle ch = (PhidgetVoltageRatioInputHandle)phid;
	switch (code) {
	case EEPHIDGET_SATURATION:
		ch->voltageRatio = PUNK_DBL;
		ch->sensorValue = PUNK_DBL;
		break;
	}
}

static PhidgetReturnCode CCONV
PhidgetVoltageRatioInput_setStatus(PhidgetChannelHandle phid, BridgePacket *bp) {
	return (_setStatus(phid, bp));
}

static PhidgetReturnCode CCONV
PhidgetVoltageRatioInput_getStatus(PhidgetChannelHandle phid, BridgePacket **bp) {
	return (_getStatus(phid, bp));
}

static PhidgetReturnCode CCONV
PhidgetVoltageRatioInput_initAfterOpen(PhidgetChannelHandle phid) {
	PhidgetVoltageRatioInputHandle ch;
	PhidgetReturnCode res;

	TESTPTR(phid);
	ch = (PhidgetVoltageRatioInputHandle)phid;

	res = _initAfterOpen(phid);
	if (res != EPHIDGET_OK)
		return (res);

	ch->sensorUnit = PhidgetAnalogSensor_getVoltageRatioSensorUnit(ch->sensorType);
	ch->sensorUnitValid = PTRUE;
	ch->sensorValue = PhidgetAnalogSensor_getVoltageRatioSensorValue(ch->voltageRatio, ch->sensorType);

	return (EPHIDGET_OK);
}

static PhidgetReturnCode CCONV
PhidgetVoltageRatioInput_setDefaults(PhidgetChannelHandle phid) {
	return (_setDefaults(phid));
}

static PhidgetReturnCode
PhidgetVoltageRatioInput_bridgeInput(PhidgetChannelHandle phid, BridgePacket *bp) {
	PhidgetVoltageRatioInputHandle ch;
	Phidget_UnitInfo unitInfo;
	PhidgetReturnCode res;
	double sensorValue;

	TESTPTR(phid);
	ch = (PhidgetVoltageRatioInputHandle)phid;

	switch (bp->vpkt) {
	case BP_MINDATAINTERVALCHANGE:
		ch->minDataInterval = getBridgePacketUInt32(bp, 0);
		FIRE_PROPERTYCHANGE(ch, "MinDataInterval");
		res = EPHIDGET_OK;
		break;
	case BP_DATAINTERVALCHANGE:
		ch->dataInterval = getBridgePacketUInt32(bp, 0);
		FIRE_PROPERTYCHANGE(ch, "DataInterval");
		res = EPHIDGET_OK;
		break;
	case BP_SETSENSORTYPE:
		if ((PhidgetVoltageRatioInput_SensorType)getBridgePacketInt32(bp, 0) != ch->sensorType)
			ch->sensorValue = PUNK_DBL;
		res = _bridgeInput(phid, bp);
		break;
	case BP_SETSENSORVALUECHANGETRIGGER:
		if (getBridgePacketDouble(bp, 0) < 0)
			return (EPHIDGET_INVALIDARG);
		res = _bridgeInput(phid, bp);
		break;
	case BP_SENSORCHANGE:
		res = readUnitInfo(bp, &unitInfo);
		if (res != EPHIDGET_OK)
			break;
		ch->sensorValue = getBridgePacketDouble(bp, 0);
		ch->sensorUnit = Phidget_Units[unitInfo.unit];
		ch->sensorUnitValid = PTRUE;
		FIRECH(ch, SensorChange, ch->sensorValue, &unitInfo);
		res = EPHIDGET_OK;
		break;
	case BP_VOLTAGERATIOCHANGE:
		ch->voltageRatio = getBridgePacketDouble(bp, 0);
		res = EPHIDGET_OK;

		if (supportedBridgePacket(phid, BP_SENSORCHANGE) && !isNetworkPhidget(ch) && ch->sensorType != SENSOR_TYPE_VOLTAGERATIO && ch->sensorType_isSet) {
			sensorValue = PhidgetAnalogSensor_getVoltageRatioSensorValue(ch->voltageRatio, ch->sensorType);
			if (!PhidgetAnalogSensor_getVoltageRatioSensorValueInRange(sensorValue, ch->sensorType)) {
				ch->sensorValue = PUNK_DBL;
				SEND_ERROR_EVENT(ch, EEPHIDGET_OUTOFRANGE, "Sensor value is ouside the valid range for this sensor.");
			} else if (ch->sensorValue == PUNK_DBL || fabs(sensorValue - ch->sensorValue) >= ch->sensorValueChangeTrigger) {
				ch->sensorValue = sensorValue;
				res = createBridgePacket(&bp, BP_SENSORCHANGE, "%g", sensorValue);
				if (res == EPHIDGET_OK) {
					unitInfo = PhidgetAnalogSensor_getVoltageRatioSensorUnit(ch->sensorType);
					res = writeUnitInfo(&unitInfo, bp);
					if (res == EPHIDGET_OK)
						res = dispatchChannelBridgePacket(phid, bp);
				}
			}
			// If we are opened by a network client, we want to stop the dispatcher from forwarding the VoltageRatioChange event to network clients
			if (res == EPHIDGET_OK && PhidgetCKFlags(ch, PHIDGET_OPENBYNETCLIENT_FLAG))
				return (EPHIDGET_UNSUPPORTED);
		} else {
			FIRECH(ch, VoltageRatioChange, ch->voltageRatio);
		}
		break;
	default:
		res = _bridgeInput(phid, bp);
		break;
	}

	return (res);
}

static void
PhidgetVoltageRatioInput_fireInitialEvents(PhidgetChannelHandle phid) {
	PhidgetVoltageRatioInputHandle ch;
	Phidget_UnitInfo unitInfo;

	ch = (PhidgetVoltageRatioInputHandle)phid;

	if (supportedBridgePacket(phid, BP_SENSORCHANGE) && !isNetworkPhidget(ch) && ch->sensorType != SENSOR_TYPE_VOLTAGERATIO && ch->sensorType_isSet) {
		if (ch->sensorValue != PUNK_DBL && ch->sensorUnitValid) {
			unitInfo = ch->sensorUnit;
			FIRECH(ch, SensorChange, ch->sensorValue, &unitInfo);
		}
	} else {
		if (ch->voltageRatio != PUNK_DBL)
			FIRECH(ch, VoltageRatioChange, ch->voltageRatio);
	}

	_fireInitialEvents(phid);
}

==> libphidget22-1.1.20190417.tar.gz: libphidget22-1.1.20190417/src/class/voltageratioinput.c <==
/* Generated: Wed Jan 27 2016 14:22:18 GMT-0700 (Mountain Standard Time) */
/* Will not be regenerated. */

#include "phidgetbase.h"
#include "analogsensor.h"
#include "class/voltageratioinput.gen.h"
#include "class/voltageratioinput.gen.c"

static void
PhidgetVoltageRatioInput_errorHandler(PhidgetChannelHandle phid, Phidget_ErrorEventCode code) {
	PhidgetVoltageRatioInputHandle ch = (PhidgetVoltageRatioInputHandle)phid;
	switch (code) {
	case EEPHIDGET_SATURATION:
		ch->voltageRatio = PUNK_DBL;
		ch->sensorValue = PUNK_DBL;
		break;
	}
}

static PhidgetReturnCode CCONV
PhidgetVoltageRatioInput_setStatus(PhidgetChannelHandle phid, BridgePacket *bp) {
	return (_setStatus(phid, bp));
}

static PhidgetReturnCode CCONV
PhidgetVoltageRatioInput_getStatus(PhidgetChannelHandle phid, BridgePacket **bp) {
	return (_getStatus(phid, bp));
}

static PhidgetReturnCode CCONV
PhidgetVoltageRatioInput_initAfterOpen(PhidgetChannelHandle phid) {
	PhidgetVoltageRatioInputHandle ch;
	PhidgetReturnCode res;

	TESTPTR(phid);
	ch = (PhidgetVoltageRatioInputHandle)phid;

	res = _initAfterOpen(phid);
	if (res != EPHIDGET_OK)
		return (res);

	ch->sensorUnit = PhidgetAnalogSensor_getVoltageRatioSensorUnit(ch->sensorType);
	ch->sensorUnitValid = PTRUE;
	ch->sensorValue = PhidgetAnalogSensor_getVoltageRatioSensorValue(ch->voltageRatio, ch->sensorType);

	return (EPHIDGET_OK);
}

static PhidgetReturnCode CCONV
PhidgetVoltageRatioInput_setDefaults(PhidgetChannelHandle phid) {
	return (_setDefaults(phid));
}

static PhidgetReturnCode
bangSensorVoltage(PhidgetChannelHandle phid, int *sentSensorEvent, int includeVoltage) {
	PhidgetVoltageRatioInputHandle ch;
	Phidget_UnitInfo unitInfo;
	PhidgetReturnCode res;
	double sensorValue;
	BridgePacket *bp;

	ch = (PhidgetVoltageRatioInputHandle)phid;
	res = EPHIDGET_OK;

	if (supportedBridgePacket(phid, BP_SENSORCHANGE) && !isNetworkPhidget(ch) && ch->sensorType != SENSOR_TYPE_VOLTAGERATIO) {
		sensorValue = PhidgetAnalogSensor_getVoltageRatioSensorValue(ch->voltageRatio, ch->sensorType);
		if (!PhidgetAnalogSensor_getVoltageRatioSensorValueInRange(sensorValue, ch->sensorType)) {
			ch->sensorValue = PUNK_DBL;
			if (ISATTACHEDDONE(ch))
				SEND_ERROR_EVENT(ch, EEPHIDGET_OUTOFRANGE, "Sensor value is ouside the valid range for this sensor.");
		} else if (ch->sensorValue == PUNK_DBL || fabs(sensorValue - ch->sensorValue) >= ch->sensorValueChangeTrigger) {
			ch->sensorValue = sensorValue;
			if (ISATTACHEDDONE(ch)) {
				res = createBridgePacket(&bp, BP_SENSORCHANGE, "%g", sensorValue);
				if (res == EPHIDGET_OK) {
					unitInfo = PhidgetAnalogSensor_getVoltageRatioSensorUnit(ch->sensorType);
					res = writeUnitInfo(&unitInfo, bp);
					if (res == EPHIDGET_OK)
						res = dispatchChannelBridgePacket(phid, bp);
				}
			}
		}
		if (res == EPHIDGET_OK)
			*sentSensorEvent = PTRUE;
	} else if (includeVoltage) {
		ch->sensorUnit = PhidgetAnalogSensor_getVoltageRatioSensorUnit(ch->sensorType);
		ch->sensorUnitValid = PTRUE;
		ch->sensorValue = PhidgetAnalogSensor_getVoltageRatioSensorValue(ch->voltageRatio, ch->sensorType);

		if (ISATTACHEDDONE(ch))
			FIRECH(ch, VoltageRatioChange, ch->voltageRatio);
	}

	return (res);
}

static PhidgetReturnCode
PhidgetVoltageRatioInput_bridgeInput(PhidgetChannelHandle phid, BridgePacket *bp) {
	PhidgetVoltageRatioInputHandle ch;
	Phidget_UnitInfo unitInfo;
	int sentSensorEvent = 0;
	PhidgetReturnCode res;

	TESTPTR(phid);
	ch = (PhidgetVoltageRatioInputHandle)phid;

	switch (bp->vpkt) {
	case BP_MINDATAINTERVALCHANGE:
		ch->minDataInterval = getBridgePacketUInt32(bp, 0);
		FIRE_PROPERTYCHANGE(ch, "MinDataInterval");
		res = EPHIDGET_OK;
		break;
	case BP_DATAINTERVALCHANGE:
		ch->dataInterval = getBridgePacketUInt32(bp, 0);
		FIRE_PROPERTYCHANGE(ch, "DataInterval");
		res = EPHIDGET_OK;
		break;
	case BP_SETSENSORTYPE:
		res = _bridgeInput(phid, bp);
		if (res == EPHIDGET_OK)
			res = bangSensorVoltage(phid, &sentSensorEvent, 0);
		break;
	case BP_SETSENSORVALUECHANGETRIGGER:
		if (getBridgePacketDouble(bp, 0) < 0)
			return (EPHIDGET_INVALIDARG);
		res = _bridgeInput(phid, bp);
		break;
	case BP_SENSORCHANGE:
		res = readUnitInfo(bp, &unitInfo);
		if (res != EPHIDGET_OK)
			break;
		ch->sensorValue = getBridgePacketDouble(bp, 0);
		ch->sensorUnit = Phidget_Units[unitInfo.unit];
		ch->sensorUnitValid = PTRUE;
		FIRECH(ch, SensorChange, ch->sensorValue, &unitInfo);
		res = EPHIDGET_OK;
		break;
	case BP_VOLTAGERATIOCHANGE:
		ch->voltageRatio = getBridgePacketDouble(bp, 0);
		res = bangSensorVoltage(phid, &sentSensorEvent, 1);
		// If we are opened by a network client, we want to stop the dispatcher from forwarding the VoltageChange event to network clients
		if (sentSensorEvent && res == EPHIDGET_OK && PhidgetCKFlags(ch, PHIDGET_OPENBYNETCLIENT_FLAG))
			res = EPHIDGET_UNSUPPORTED;
		break;
	default:
		res = _bridgeInput(phid, bp);
		break;
	}

	return (res);
}

static void
PhidgetVoltageRatioInput_fireInitialEvents(PhidgetChannelHandle phid) {
	PhidgetVoltageRatioInputHandle ch;
	Phidget_UnitInfo unitInfo;

	ch = (PhidgetVoltageRatioInputHandle)phid;

	if (supportedBridgePacket(phid, BP_SENSORCHANGE) && !isNetworkPhidget(ch) && ch->sensorType != SENSOR_TYPE_VOLTAGERATIO) {
		if (ch->sensorValue != PUNK_DBL && ch->sensorUnitValid) {
			unitInfo = ch->sensorUnit;
			FIRECH(ch, SensorChange, ch->sensorValue, &unitInfo);
		}
	} else {
		if (ch->voltageRatio != PUNK_DBL)
			FIRECH(ch, VoltageRatioChange, ch->voltageRatio);
	}

	_fireInitialEvents(phid);
}
